aboutsummaryrefslogtreecommitdiff
path: root/engines/titanic/pet_control/pet_remote_glyphs.h
diff options
context:
space:
mode:
authorPaul Gilbert2016-05-02 19:23:29 -0400
committerPaul Gilbert2016-07-10 16:38:08 -0400
commit9a6ad7d1e012a5cb1a4ca955b0f738f12c0a7874 (patch)
treeb42b03e7a68a6ce814ee3f5a46a56eb26b8b32e1 /engines/titanic/pet_control/pet_remote_glyphs.h
parent947d9e344c2e51c7ad8e4fe1f78fb131cafc921a (diff)
downloadscummvm-rg350-9a6ad7d1e012a5cb1a4ca955b0f738f12c0a7874.tar.gz
scummvm-rg350-9a6ad7d1e012a5cb1a4ca955b0f738f12c0a7874.tar.bz2
scummvm-rg350-9a6ad7d1e012a5cb1a4ca955b0f738f12c0a7874.zip
TITANIC: Implemented remote entertainment device glyph
Diffstat (limited to 'engines/titanic/pet_control/pet_remote_glyphs.h')
-rw-r--r--engines/titanic/pet_control/pet_remote_glyphs.h34
1 files changed, 29 insertions, 5 deletions
diff --git a/engines/titanic/pet_control/pet_remote_glyphs.h b/engines/titanic/pet_control/pet_remote_glyphs.h
index 8a9cb88e99..e8f0c8d8c7 100644
--- a/engines/titanic/pet_control/pet_remote_glyphs.h
+++ b/engines/titanic/pet_control/pet_remote_glyphs.h
@@ -30,7 +30,7 @@ namespace Titanic {
enum RemoteGlyph {
GLYPH_SUMMON_ELEVATOR = 0, GLYPH_SUMMON_PELLERATOR = 1,
- GLYPH_TELEVISION_CONTROL = 2
+ GLYPH_TELEVISION_CONTROL = 2, GLYPH_ENTERTAINMENT_DEVICE = 3
};
enum RemoteMessage {
@@ -126,9 +126,14 @@ public:
virtual void draw2(CScreenManager *screenManager);
/**
* Called for mouse button down messages
*/
- virtual bool MouseButtonDownMsg(const Point &pt);
+ bool elementMouseButtonDownMsg(const Point &pt);
+
+ /**
+ * Called for mouse button up messages to the default element
+ */
+ bool elementMouseButtonUpMsg(const Point &pt);
};
class CSummonElevatorGlyph : public CBasicRemoteGlyph {
@@ -179,17 +184,36 @@ public:
class CEntertainmentDeviceGlyph : public CToggleRemoteGlyph {
public:
- int _field3C;
+ bool _flag2;
CPetGfxElement *_gfxElement2, *_gfxElement3;
public:
CEntertainmentDeviceGlyph() : CToggleRemoteGlyph(),
- _field3C(0), _gfxElement2(nullptr), _gfxElement3(nullptr) {}
+ _flag2(false), _gfxElement2(nullptr), _gfxElement3(nullptr) {}
/**
* Setup the glyph
*/
virtual bool setup(CPetControl *petControl, CPetGlyphs *owner);
+ /**
+ * Handles any secondary drawing of the glyph
+ */
+ virtual void draw2(CScreenManager *screenManager);
+
+ /**
+ * Called for mouse button down messages
+ */
+ virtual bool MouseButtonDownMsg(const Point &pt);
+
+ /**
+ * Handles mouse button up messages
+ */
+ virtual bool MouseButtonUpMsg(const Point &pt);
+
+ /**
+ * Returns the tooltip text for when the glyph is selected
+ */
+ virtual void getTooltip(CPetText *text);
};
} // End of namespace Titanic
@@ -126,9 +126,14 @@ public:
virtual void draw2(CScreenManager *screenManager);
/**
- * Called for mouse button down messages
+ * Called for mouse button down messages to the default element
*/